==> gdhcpd_0.2.8.orig.tar.gz: gdhcpd-0.2.8/src/reread_conf.c <==
/* GDHCPD, a GTK+ frontend for ISC DHCPD
 * Copyright C 2004, 2005 Magnus Loef <magnus-swe@telia.com> 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 *
*/


#include <gtk/gtk.h>
#include <stdio.h>
#include <string.h>
#include "widgets.h"
#include "gettext.h"
#include "commands.h"

extern int activated;
extern char DHCPD_CONF_BUF[1024];


void reread_conf()
{
    /* It doesnt restart/reread with a HUP, no problem */
    gchar *command, *test;

    if( ! activated )
      return;

    command = g_strdup_printf("killall -15 %s", DHCPD_BINARY);
    if( ! run_command(command) )
      printf("dhcpd shutdown failed, trying to start it\n");

    g_free(command);

    command = g_strdup_printf("%s -cf %s", DHCPD_BINARY, DHCPD_CONF_BUF);
    if( ! run_command(command) )
    {
        printf("Restarting dhcpd failed\n");
        test = g_strdup_printf("%s -cf %s 2>&1", DHCPD_BINARY, DHCPD_CONF_BUF);
	run_command_show_err(test);
	g_free(test);
    }
    g_free(command);
}

==> gdhcpd_0.2.9.orig.tar.gz: gdhcpd-0.2.9/src/reread_conf.c <==
/* GDHCPD, a GTK+ frontend for ISC DHCPD
 * Copyright C 2004, 2005, 2006 Magnus Loef <magnus-swe@telia.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 *
*/


#include "../config.h"
#include <gtk/gtk.h>
#include <stdio.h>
#include <string.h>
#include "widgets.h"
#include "gettext.h"
#include "commands.h"

extern int activated;
extern char DHCPD_CONF_BUF[1024];


void reread_conf()
{
    /* It doesnt restart/reread with a HUP, no problem */
    gchar *command, *test;

    if( ! activated )
      return;

    command = g_strdup_printf("killall -15 %s", DHCPD_BINARY);
    if( ! run_command(command) )
      printf("dhcpd shutdown failed, trying to start it\n");

    g_free(command);


    command = g_strdup_printf("%s -cf %s 2>&1", DHCPD_BINARY, DHCPD_CONF_BUF);
    if( ! run_command(command) )
    {
        printf("Restarting dhcpd failed\n");
        test = g_strdup_printf("%s -cf %s 2>&1", DHCPD_BINARY, DHCPD_CONF_BUF);
	run_command_show_err(test);
	g_free(test);
    }
    g_free(command);
}
